Kinto
=====

|travis| |master-coverage| |readthedocs|

.. |travis| image:: https://travis-ci.org/Kinto/kinto.svg?branch=master
    :target: https://travis-ci.org/Kinto/kinto

.. |readthedocs| image:: https://readthedocs.org/projects/kinto/badge/?version=latest
    :target: http://kinto.readthedocs.org/en/latest/
    :alt: Documentation Status

.. |master-coverage| image::
    https://coveralls.io/repos/Kinto/kinto/badge.png?branch=master
    :alt: Coverage
    :target: https://coveralls.io/r/Kinto/kinto

Kinto is a server allowing you to store and synchronize arbitrary data,
attached to your Firefox account.

* `Online documentation <http://kinto.readthedocs.org/en/latest/>`_
* `Tutorial <http://kinto.readthedocs.org/en/latest/tutorial.html>`_
* `Issue tracker <https://github.com/Kinto/kinto/issues>`_
* `Contributing <http://kinto.readthedocs.org/en/latest/contributing.html>`_
* `Try our daily flushed instance at: https://kinto.dev.mozaws.net/v1/ <https://kinto.dev.mozaws.net/v1/>`_
